package com.alihealth.d2d.provtest.entity;

import org.springframework.data.annotation.Id;

import javax.persistence.*;
import javax.xml.bind.annotation.XmlTransient;
import java.time.LocalDateTime;

/**
 * @author Jason
 * @date 2025年05月30日 09:55:20
 */
@MappedSuperclass
@XmlTransient
public abstract class BaseEntity<T extends BaseEntity<T>> implements XmlEntity<T>{
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;

    @Column(name = "event_id")
    private String eventId;//事件流水号

    @Column(name = "create_time", updatable = false)
    // 仅数据库字段
    private LocalDateTime createTime = LocalDateTime.now();

    @Column(name = "update_time")
    private LocalDateTime updateTime;

    @PreUpdate
    public void preUpdate() {
        this.updateTime = LocalDateTime.now();
    }

    // 子类必须实现这两个方法
    public abstract Class<T> getEntityClass();
    public abstract String getDatasetName();
}

