package com.alihealth.d2d.provtest.factory;

import com.alihealth.d2d.provtest.domain.DomesticPharmaBaseInfo;
import com.alihealth.d2d.provtest.utils.XmlStringParser;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;


/**
 * @author Jason 子类型1011的工厂
 * @date 2025年05月29日 15:09:50
 */
public class DomesticPharmaBaseInfoFactory implements EntityFactory {

    private static final Logger logger = LoggerFactory.getLogger(DomesticPharmaBaseInfoFactory.class);

    public Object createEntity() {
        return new DomesticPharmaBaseInfo();
    }

    @Override
    public String getSupportedSubType() {
        return "1011";
    }


    @Override
    public void populateEntity(Object entity, org.w3c.dom.Element dataElement) {
        if (!(entity instanceof DomesticPharmaBaseInfo)) {
            return;
        }

        DomesticPharmaBaseInfo baseInfo = (DomesticPharmaBaseInfo) entity;
        baseInfo.setTyshxydm(getElementText(dataElement, "TYSHXYDM"));
        baseInfo.setJnypscqymc(getElementText(dataElement, "JNYPSCQYMC"));
        baseInfo.setJnypscqylx(getElementText(dataElement, "JNYPSCQYLX"));
        baseInfo.setZsdz(getElementText(dataElement, "ZSDZ"));
        baseInfo.setZsdzgjhdq(getElementText(dataElement, "ZSDZGJHDQ"));
        baseInfo.setZsdzszxszzq(getElementText(dataElement, "ZSDZSZXSZZQ"));
        baseInfo.setJnypscqylx(getElementText(dataElement, "JNYPSCQYLX"));
        baseInfo.setZsdzsqzzzm(getElementText(dataElement, "ZSDZSQZZZM"));
        baseInfo.setZsdzxzzxxjs(getElementText(dataElement, "ZSDZXZZXXJS"));
        baseInfo.setZsdzxzjdbsc(getElementText(dataElement, "ZSDZXZJDBSC"));

        baseInfo.setZsdzcjlld(getElementText(dataElement, "ZSDZCJLLD"));
        baseInfo.setZsdzmphm(getElementText(dataElement, "ZSDZMPHM"));
        baseInfo.setFddbr(getElementText(dataElement, "FDDBR"));
        baseInfo.setZczb(getElementText(dataElement, "ZCZB"));
        baseInfo.setClrq(parseDate(getElementText(dataElement, "CLRQ")));
        baseInfo.setYyqx(getElementText(dataElement, "YYQX"));
        baseInfo.setJyfw(getElementText(dataElement, "JYFW"));
        baseInfo.setDjjg(getElementText(dataElement, "DJJG"));
        baseInfo.setGddhhm(getElementText(dataElement, "GDDHHM"));
        baseInfo.setCzhm(getElementText(dataElement, "CZHM"));
        baseInfo.setDzxx(getElementText(dataElement, "DZXX"));
        baseInfo.setQywz(getElementText(dataElement, "QYWZ"));
        baseInfo.setLxr(getElementText(dataElement, "LXR"));

        baseInfo.setLxdh(getElementText(dataElement, "LXDH"));
        baseInfo.setZsgps(getElementText(dataElement, "ZSGPS"));


    }


    private static String getElementText(org.w3c.dom.Element parent, String tagName) {
        NodeList nodeList = parent.getElementsByTagName(tagName);
        if (nodeList.getLength() > 0) {
            Node node = nodeList.item(0);
            return node.getTextContent().trim();
        }
        return null;
    }

    private static LocalDate parseDate(String dateStr) {
        if (dateStr == null || dateStr.length() != 8 || "无".equals(dateStr)) {
            return null;
        }

        try {
            DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyyMMdd");
            return LocalDate.parse(dateStr, formatter);
        } catch (Exception e) {
            logger.warn("日期解析失败: " + dateStr, e);
            return null;
        }
    }

}
