package com.alihealth.d2d.provtest.service;

import org.springframework.stereotype.Service;
import org.w3c.dom.Document;
import org.w3c.dom.NodeList;
import org.xml.sax.InputSource;

import javax.xml.XMLConstants;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.Unmarshaller;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.stream.XMLInputFactory;
import javax.xml.stream.XMLStreamReader;
import java.io.StringReader;
import java.io.StringWriter;
import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * @author Jason
 * @date 2025年05月30日 11:41:26
 */
@Service
public class XmlParserService {


    /**
     * 解析包含多个data节点的XML
     * @param xml 完整XML内容
     * @param wrapperClass 外层包装类（如VTTSBasic.class）
     * @param dataClass 内部data节点对应的实体类
     */
    public <T> List<T> parseMultiDataXml(
            String xml,
            Class<?> wrapperClass,
            Class<T> dataClass) throws Exception {

        JAXBContext context = JAXBContext.newInstance(wrapperClass, dataClass);
        Unmarshaller unmarshaller = context.createUnmarshaller();

        // 使用StAX提高安全性
        XMLInputFactory xif = XMLInputFactory.newInstance();
        xif.setProperty(XMLInputFactory.IS_SUPPORTING_EXTERNAL_ENTITIES, false);
        xif.setProperty(XMLInputFactory.SUPPORT_DTD, false);

        XMLStreamReader xsr = xif.createXMLStreamReader(new StringReader(xml));

        JAXBElement<?> root = unmarshaller.unmarshal(xsr, wrapperClass);
        Field datasetField = wrapperClass.getDeclaredField("dataset");
        datasetField.setAccessible(true);

        @SuppressWarnings("unchecked")
        List<T> result = (List<T>) datasetField.get(root.getValue());

        return result != null ? result : Collections.emptyList();
    }
}
