package com.alihealth.d2d.provtest.utils;

import org.bouncycastle.asn1.x500.X500Name;
import org.bouncycastle.cert.X509v3CertificateBuilder;
import org.bouncycastle.cert.jcajce.JcaX509CertificateConverter;
import org.bouncycastle.cert.jcajce.JcaX509v3CertificateBuilder;
import org.bouncycastle.jce.provider.BouncyCastleProvider;
import org.bouncycastle.operator.ContentSigner;
import org.bouncycastle.operator.jcajce.JcaContentSignerBuilder;

import java.io.FileOutputStream;
import java.math.BigInteger;
import java.security.KeyPair;
import java.security.KeyPairGenerator;
import java.security.KeyStore;
import java.security.Security;
import java.security.cert.X509Certificate;
import java.util.Date;

/**
 * @author Jason
 * @date 2025年05月28日 15:02:12
 */
public class BouncyCastlePFXGenerator {

    static {
        Security.addProvider(new BouncyCastleProvider());
    }

    public static void generatePFX(String pfxFilePath, String password) throws Exception {
        // 1. 生成密钥对
        KeyPairGenerator keyPairGenerator = KeyPairGenerator.getInstance("RSA");
        keyPairGenerator.initialize(2048);
        KeyPair keyPair = keyPairGenerator.generateKeyPair();

        // 2. 创建自签名证书
        X500Name issuerName = new X500Name("CN=Test Certificate, OU=Test, O=Test Org, C=US");
        BigInteger serialNumber = BigInteger.valueOf(System.currentTimeMillis());
        Date notBefore = new Date();
        Date notAfter = new Date(System.currentTimeMillis() + 365L * 24 * 60 * 60 * 1000); // 1年有效期

        X509v3CertificateBuilder certBuilder = new JcaX509v3CertificateBuilder(
                issuerName, serialNumber, notBefore, notAfter, issuerName, keyPair.getPublic());

        ContentSigner signer = new JcaContentSignerBuilder("SHA256WithRSAEncryption")
                .build(keyPair.getPrivate());

        X509Certificate cert = new JcaX509CertificateConverter()
                .getCertificate(certBuilder.build(signer));

        // 3. 创建PKCS12密钥库
        KeyStore pkcs12 = KeyStore.getInstance("PKCS12");
        pkcs12.load(null, null);

        // 4. 添加证书和私钥
        pkcs12.setKeyEntry("alias", keyPair.getPrivate(), password.toCharArray(),
                new java.security.cert.Certificate[]{cert});

        // 5. 保存PFX文件
        try (FileOutputStream fos = new FileOutputStream(pfxFilePath)) {
            pkcs12.store(fos, password.toCharArray());
        }
    }

    public static void main(String[] args) {
        try {
            generatePFX("d2d.pfx", "12345678");
            System.out.println("使用Bouncy Castle生成的PFX证书成功!");
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
